.. Bedrock Server Manager Windows Task Scheduler Core documentation file

Windows Task Scheduler Core Documentation
=========================================

.. autoclass:: bedrock_server_manager.core.system.task_scheduler.WindowsTaskScheduler
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

   .. automethod:: __init__